==> v21.10.zip: bookstack/resources/lang/vi/activities.php <==
<?php
/**
 * Activity text strings.
 * Is used for all the text within activity logs & notifications.
 */
return [

    // Pages
    'page_create'                 => 'đã tạo trang',
    'page_create_notification'    => 'Trang đã được tạo thành công',
    'page_update'                 => 'đã cập nhật trang',
    'page_update_notification'    => 'Trang đã được cập nhật thành công',
    'page_delete'                 => 'đã xóa trang',
    'page_delete_notification'    => 'Trang đã được xóa thành công',
    'page_restore'                => 'đã khôi phục trang',
    'page_restore_notification'   => 'Trang đã được khôi phục thành công',
    'page_move'                   => 'đã di chuyển trang',

    // Chapters
    'chapter_create'              => 'đã tạo chương',
    'chapter_create_notification' => 'Chương đã được tạo thành công',
    'chapter_update'              => 'đã cập nhật chương',
    'chapter_update_notification' => 'Chương đã được cập nhật thành công',
    'chapter_delete'              => 'đã xóa chương',
    'chapter_delete_notification' => 'Chương đã được xóa thành công',
    'chapter_move'                => 'đã di chuyển chương',

    // Books
    'book_create'                 => 'đã tạo sách',
    'book_create_notification'    => 'Sách đã được tạo thành công',
    'book_update'                 => 'đã cập nhật sách',
    'book_update_notification'    => 'Sách đã được cập nhật thành công',
    'book_delete'                 => 'đã xóa sách',
    'book_delete_notification'    => 'Sách đã được xóa thành công',
    'book_sort'                   => 'đã sắp xếp sách',
    'book_sort_notification'      => 'Sách đã được sắp xếp lại thành công',

    // Bookshelves
    'bookshelf_create'            => 'đã tạo giá sách',
    'bookshelf_create_notification'    => 'Giá sách đã được tạo thành công',
    'bookshelf_update'                 => 'cập nhật giá sách',
    'bookshelf_update_notification'    => 'Giá sách đã tạo thành công',
    'bookshelf_delete'                 => 'đã xóa giá sách',
    'bookshelf_delete_notification'    => 'Giá sách đã được xóa thành công',

    // Favourites
    'favourite_add_notification' => '":name" đã được thêm vào danh sách yêu thích của bạn',
    'favourite_remove_notification' => '":name" đã được gỡ khỏi danh sách yêu thích của bạn',

    // MFA
    'mfa_setup_method_notification' => 'Cấu hình xác thực nhiều bước thành công',
    'mfa_remove_method_notification' => 'Đã gỡ xác thực nhiều bước',

    // Other
    'commented_on'                => 'đã bình luận về',
    'permissions_update'          => 'các quyền đã được cập nhật',
];

==> v22.11.zip: bookstack/resources/lang/vi/activities.php <==
<?php
/**
 * Activity text strings.
 * Is used for all the text within activity logs & notifications.
 */
return [

    // Pages
    'page_create'                 => 'đã tạo trang',
    'page_create_notification'    => 'Trang đã được tạo thành công',
    'page_update'                 => 'đã cập nhật trang',
    'page_update_notification'    => 'Trang đã được cập nhật thành công',
    'page_delete'                 => 'đã xóa trang',
    'page_delete_notification'    => 'Trang đã được xóa thành công',
    'page_restore'                => 'đã khôi phục trang',
    'page_restore_notification'   => 'Trang đã được khôi phục thành công',
    'page_move'                   => 'đã di chuyển trang',

    // Chapters
    'chapter_create'              => 'đã tạo chương',
    'chapter_create_notification' => 'Chương đã được tạo thành công',
    'chapter_update'              => 'đã cập nhật chương',
    'chapter_update_notification' => 'Chương đã được cập nhật thành công',
    'chapter_delete'              => 'đã xóa chương',
    'chapter_delete_notification' => 'Chương đã được xóa thành công',
    'chapter_move'                => 'đã di chuyển chương',

    // Books
    'book_create'                 => 'đã tạo sách',
    'book_create_notification'    => 'Sách đã được tạo thành công',
    'book_create_from_chapter'              => 'converted chapter to book',
    'book_create_from_chapter_notification' => 'Chapter successfully converted to a book',
    'book_update'                 => 'đã cập nhật sách',
    'book_update_notification'    => 'Sách đã được cập nhật thành công',
    'book_delete'                 => 'đã xóa sách',
    'book_delete_notification'    => 'Sách đã được xóa thành công',
    'book_sort'                   => 'đã sắp xếp sách',
    'book_sort_notification'      => 'Sách đã được sắp xếp lại thành công',

    // Bookshelves
    'bookshelf_create'            => 'created shelf',
    'bookshelf_create_notification'    => 'Shelf successfully created',
    'bookshelf_create_from_book'    => 'converted book to shelf',
    'bookshelf_create_from_book_notification'    => 'Book successfully converted to a shelf',
    'bookshelf_update'                 => 'updated shelf',
    'bookshelf_update_notification'    => 'Shelf successfully updated',
    'bookshelf_delete'                 => 'deleted shelf',
    'bookshelf_delete_notification'    => 'Shelf successfully deleted',

    // Favourites
    'favourite_add_notification' => '":name" đã được thêm vào danh sách yêu thích của bạn',
    'favourite_remove_notification' => '":name" đã được gỡ khỏi danh sách yêu thích của bạn',

    // MFA
    'mfa_setup_method_notification' => 'Cấu hình xác thực nhiều bước thành công',
    'mfa_remove_method_notification' => 'Đã gỡ xác thực nhiều bước',

    // Webhooks
    'webhook_create' => 'đã tạo webhook',
    'webhook_create_notification' => 'Webhook đã được tạo thành công',
    'webhook_update' => 'đã cập nhật webhook',
    'webhook_update_notification' => 'Webhook đã được cập nhật thành công',
    'webhook_delete' => 'đã xóa webhook',
    'webhook_delete_notification' => 'Webhook đã được xóa thành công',

    // Users
    'user_update_notification' => 'Người dùng được cập nhật thành công',
    'user_delete_notification' => 'Người dùng đã được xóa thành công',

    // Other
    'commented_on'                => 'đã bình luận về',
    'permissions_update'          => 'các quyền đã được cập nhật',
];
